@@ -141,6 +141,17 @@ class Pipeline:
         elif kind == "obj":
             return self._Results
     
+    def results( self ):
+        """
+        Returns
+        -------
+        Results : qpcr.Results
+            The `qpcr.Results` object storing the pipelines data.
+            Note, this is equivalent to `get( kind = "obj" )`.
+        """
+        return self._Results
+
+
     def link(self, assays:(list or str) = None, normalisers:(list or str) = None):
         """
         Links new assays-of-interest / sample assays and/or normaliser assays 
@@ -466,11 +477,15 @@ class Blueprint(BasicPlus):
                         filters = filters
                     )
         
-        self._Normaliser.prune(
-                                assays = assays, 
-                                normalisers = normalisers, 
-                                results = results
-                            )
+        try: 
+            self._Normaliser.prune(
+                                    assays = assays, 
+                                    normalisers = normalisers, 
+                                    results = results
+                                )
+        except: 
+            pass
+        
         if cores: 
             self._Reader = None
             self._Analyser = None
@@ -593,8 +608,8 @@ class Blueprint(BasicPlus):
                         filter.report(self._save_to)
 
                 # save filter summary fig
-                figs = filter.plot()
-                self._Figures.extend(figs)
+                fig = filter.plot()
+                self._Figures.append(fig)
 
         # plot results
         if have_plotters:
@@ -853,8 +868,8 @@ class ddCt(Blueprint):
                         filter.report(self._save_to)
 
                 # save filter summary fig
-                figs = filter.plot()
-                self._Figures.extend(figs)
+                fig = filter.plot()
+                self._Figures.append(fig)
 
         # plot results
         if have_plotters:
